@@ -1,5 +1,5 @@
 package Koha::Contrib::ARK::Writer;
-$Koha::Contrib::ARK::Writer::VERSION = '1.0.1';
+$Koha::Contrib::ARK::Writer::VERSION = '1.0.2';
 # ABSTRACT: Write biblio records into Koha Catalog
 use Moose;
 
@@ -22,7 +22,7 @@ sub write {
         my $fc = GetFrameworkCode($biblionumber);
         ModBiblio( $record->as('Legacy'), $biblionumber, $fc );
     }
-    $self->ark->log->info("BIBLIO AFTER PROCESSING:\n", $record->as('Text'));
+    $self->ark->log->debug("BIBLIO AFTER PROCESSING:\n", $record->as('Text'));
 }
 
 
@@ -40,7 +40,7 @@ Koha::Contrib::ARK::Writer - Write biblio records into Koha Catalog
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 ATTRIBUTES
 
